API Documentation
=================

Reference material for public API.

Core classes
------------

.. toctree::
    :maxdepth: 1

    src/api/gaplic
    src/api/gobj
    src/api/smachine
    src/api/gconfig


Essential Timer GObjs
-----------------------------

.. toctree::
    :maxdepth: 1

    src/api/c_timer


Essential Communication GObjs
-----------------------------

.. toctree::
    :maxdepth: 1

    src/api/c_sock
    src/api/c_srv_sock
    src/api/c_connex


HTTP server
-----------

.. toctree::
    :maxdepth: 1

    src/api/c_http_server


WSGI server
-----------

.. toctree::
    :maxdepth: 1

    src/api/c_wsgi_server

Sockjs server
-------------

.. toctree::
    :maxdepth: 1

    src/api/c_sockjs_server
